pub enum KeyPairAlgorithm {
Ed25519,
}Expand description
Key pair types supported by the system
Variants
Ed25519
Ed25519 elliptic curve signature scheme
Implementations
Sourceimpl KeyPairAlgorithm
impl KeyPairAlgorithm
Sourcepub fn generate_keypair(&self) -> Result<KeyPair, CryptoError>
pub fn generate_keypair(&self) -> Result<KeyPair, CryptoError>
Generate a new key pair for this algorithm
This is a convenience method that creates a new random key pair of the specified algorithm type.
Example
use ave_identity::keys::KeyPairAlgorithm;
let algorithm = KeyPairAlgorithm::Ed25519;
let keypair = algorithm.generate_keypair().unwrap();Trait Implementations
Sourceimpl Clone for KeyPairAlgorithm
impl Clone for KeyPairAlgorithm
Sourcefn clone(&self) -> KeyPairAlgorithm
fn clone(&self) -> KeyPairAlgorithm
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeyPairAlgorithm
impl Debug for KeyPairAlgorithm
Sourceimpl Default for KeyPairAlgorithm
impl Default for KeyPairAlgorithm
Sourcefn default() -> KeyPairAlgorithm
fn default() -> KeyPairAlgorithm
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for KeyPairAlgorithm
impl<'de> Deserialize<'de> for KeyPairAlgorithm
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Display for KeyPairAlgorithm
impl Display for KeyPairAlgorithm
Sourceimpl From<DSAlgorithm> for KeyPairAlgorithm
impl From<DSAlgorithm> for KeyPairAlgorithm
Sourcefn from(algo: DSAlgorithm) -> Self
fn from(algo: DSAlgorithm) -> Self
Converts to this type from the input type.
Sourceimpl From<KeyPairAlgorithm> for DSAlgorithm
impl From<KeyPairAlgorithm> for DSAlgorithm
Sourcefn from(kp_type: KeyPairAlgorithm) -> Self
fn from(kp_type: KeyPairAlgorithm) -> Self
Converts to this type from the input type.
Sourceimpl PartialEq for KeyPairAlgorithm
impl PartialEq for KeyPairAlgorithm
Sourceimpl Serialize for KeyPairAlgorithm
impl Serialize for KeyPairAlgorithm
impl Copy for KeyPairAlgorithm
impl Eq for KeyPairAlgorithm
impl StructuralPartialEq for KeyPairAlgorithm